@@ -39,7 +39,7 @@ def dark_cga():
 
 
 def light_cga():
-    return ['gray'] + [str('light %s' % name) for name in _cga_colour_names()]  + ['white']
+    return ['gray'] + [f'light {name}' for name in _cga_colour_names()]  + ['white']
 
 
 def cga():
